<script type="text/javascript" src="https://widget.clutch.co/static/js/widget.js"></script>
<div class="clutch-widget" data-url="https://widget.clutch.co" data-widget-type="2" data-height="50" data-clutchcompany-id="{{ company_id }}"></div>
